// Copyright (c) 2012 Ecma International.  All rights reserved.
// Ecma International makes this code available under the terms and conditions set
// forth on http://hg.ecmascript.org/tests/test262/raw-file/tip/LICENSE (the
// "Use Terms").   Any redistribution of this code must retain the above
// copyright and this notice and otherwise comply with the Use Terms.

/*---
es5id: 15.2.3.6-4-360-3
description: >
    ES5 Attributes - Updating data property 'P' whose attributes are
    [[Writable]]: false, [[Enumerable]]: true, [[Configurable]]: true
    to an accessor property, 'O' is the global object (8.12.9 - step
    9.b.i)
includes:
    - propertyHelper.js
    - fnGlobalObject.js
---*/

var obj = fnGlobalObject();
try {
    Object.defineProperty(obj, "prop", {
        value: 2010,
        writable: false,
        enumerable: true,
        configurable: true
    });
    var desc1 = Object.getOwnPropertyDescriptor(obj, "prop");

    function getFunc() {
        return 20;
    }
    Object.defineProperty(obj, "prop", {
        get: getFunc
    });
    var desc2 = Object.getOwnPropertyDescriptor(obj, "prop");

    assert(desc1.hasOwnProperty("value"));
    assert(desc2.hasOwnProperty("get"));
    assert.sameValue(desc2.enumerable, true);
    assert.sameValue(desc2.configurable, true);
    assert.sameValue(obj.prop, 20);
    assert.sameValue(typeof desc2.set, "undefined");
    assert.sameValue(desc2.get, getFunc);
} finally {
    delete obj.prop;
}
